Package: reproresearchR
Type: Package
Title: Companion Package for 'Reproducible Research Using R'
Version: 0.1.1
Authors@R: 
    person("Christian", "Martinez", 
           email = "c.martinez0@outlook.com", 
           role = c("aut", "cre"))
Description: Provides teaching datasets and helper functions to support the open
    educational resource Martinez (2026) "Reproducible Research Using R"
    <doi:10.5281/zenodo.19136755>. The package includes datasets used throughout
    the book and utilities to list and copy chapter scripts shipped with the package.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.3
LazyData: true
Depends: R (>= 3.5.0)
Suggests: rstudioapi
URL:
        https://martinezc1-reproducible-research-using-r.share.connect.posit.cloud/,
        https://github.com/martinezc1/reproresearchR
BugReports: https://github.com/martinezc1/reproresearchR/issues
NeedsCompilation: no
Packaged: 2026-03-20 23:09:45 UTC; christianmartinez
Author: Christian Martinez [aut, cre]
Maintainer: Christian Martinez <c.martinez0@outlook.com>
Repository: CRAN
Date/Publication: 2026-03-25 20:50:06 UTC
Built: R 4.6.0; ; 2026-04-25 21:48:00 UTC; unix
